@@ -55,7 +55,6 @@ lw_applet_realize (GtkWidget *widget)
     id = strid[strlen(strid)-1] - '0';
     desktop_plugin->priv->view = id;
     g_free(strid); 
-    
 
     switch (id){
 	    case 0: child_argv[1] = "1";
@@ -66,6 +65,17 @@ lw_applet_realize (GtkWidget *widget)
 		break;
 	    case 3: child_argv[1] = "4";
 		break;
+	    case 4: child_argv[1] = "5";
+		break;
+	    case 5: child_argv[1] = "6";
+		break;
+	    case 6: child_argv[1] = "7";
+		break;
+	    case 7: child_argv[1] = "8";
+		break;
+	    case 8: child_argv[1] = "9";
+		break;
+
     }
     desktop_plugin->priv->one_in_all_view = get_one_in_all_views_from_config();
     /* Check one theme in all view mode */
@@ -100,7 +110,7 @@ init_applet_position(gint *xapplet, gint *yapplet)
   GError *error = NULL;
   gint i;
   GConfClient   *gconf_client = gconf_client_get_default ();
-  for (i=0;i<4;i++){
+  for (i=0;i<9;i++){
       position_key = g_strdup_printf (GCONF_KEY_POSITION, i);
       position = gconf_client_get_list (gconf_client,
                                         position_key,
@@ -193,6 +203,42 @@ desktop_plugin_visible_notify (GObject    *object,
 				send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
 					  LIVEWP_SIGNAL_PATH, LIVEWP_PAUSE_LIVEBG_ON_VIEW4);
 			break;
+	       case 5: if (visible)
+				send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_PLAY_LIVEBG_ON_VIEW5);
+			else
+				send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_PAUSE_LIVEBG_ON_VIEW5);
+			break;
+	       case 6: if (visible)
+				send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_PLAY_LIVEBG_ON_VIEW6);
+			else
+				send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_PAUSE_LIVEBG_ON_VIEW6);
+			break;
+	       case 7: if (visible)
+				send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_PLAY_LIVEBG_ON_VIEW7);
+			else
+				send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_PAUSE_LIVEBG_ON_VIEW7);
+			break;
+	       case 8: if (visible)
+				send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_PLAY_LIVEBG_ON_VIEW8);
+			else
+				send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_PAUSE_LIVEBG_ON_VIEW8);
+			break;
+	       case 9: if (visible)
+				send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_PLAY_LIVEBG_ON_VIEW9);
+			else
+				send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_PAUSE_LIVEBG_ON_VIEW9);
+			break;
+
 	     }
 
      }
@@ -215,6 +261,23 @@ send_alive_event(Animation_WallpaperPrivate *priv)
 	case 4: send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
 				  LIVEWP_SIGNAL_PATH, LIVEWP_ALIVE_LIVEBG_ON_VIEW4);
 		break;
+	case 5: send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+				  LIVEWP_SIGNAL_PATH, LIVEWP_ALIVE_LIVEBG_ON_VIEW5);
+		break;
+	case 6: send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+				  LIVEWP_SIGNAL_PATH, LIVEWP_ALIVE_LIVEBG_ON_VIEW6);
+		break;
+	case 7: send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+				  LIVEWP_SIGNAL_PATH, LIVEWP_ALIVE_LIVEBG_ON_VIEW7);
+		break;
+	case 8: send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+				  LIVEWP_SIGNAL_PATH, LIVEWP_ALIVE_LIVEBG_ON_VIEW8);
+		break;
+	case 9: send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+				  LIVEWP_SIGNAL_PATH, LIVEWP_ALIVE_LIVEBG_ON_VIEW9);
+		break;
+
+
     }
 
     return TRUE;
@@ -295,6 +358,21 @@ fprintf(stderr,"lw_applet_finalize\n");
 		case 4: send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
 					  LIVEWP_SIGNAL_PATH, LIVEWP_STOP_LIVEBG_ON_VIEW4);
 			break;
+		case 5: send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_STOP_LIVEBG_ON_VIEW5);
+			break;
+		case 6: send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_STOP_LIVEBG_ON_VIEW6);
+			break;
+		case 7: send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_STOP_LIVEBG_ON_VIEW7);
+			break;
+		case 8: send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_STOP_LIVEBG_ON_VIEW8);
+			break;
+		case 9: send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_STOP_LIVEBG_ON_VIEW9);
+			break;
 	     }
      }
      if(priv->alive_timer > 0) 
